@@ -64,7 +64,7 @@ using namespace AVC;
 
 namespace BeBoB {
 
-Device::Device( DeviceManager& d, std::auto_ptr< ConfigRom >( configRom ) )
+Device::Device( DeviceManager& d, ffado_smartptr< ConfigRom >( configRom ) )
     : GenericAVC::Device( d, configRom )
     , m_last_discovery_config_id ( 0xFFFFFFFFFFFFFFFFLLU )
     , m_Mixer ( 0 )
@@ -130,7 +130,7 @@ Device::probe( Util::Configuration& c, ConfigRom& configRom, bool generic )
 }
 
 FFADODevice *
-Device::createDevice(DeviceManager& d, std::auto_ptr<ConfigRom>( configRom ))
+Device::createDevice(DeviceManager& d, ffado_smartptr<ConfigRom>( configRom ))
 {
     unsigned int vendorId = configRom->getNodeVendorId();
     unsigned int modelId = configRom->getModelId();
@@ -150,7 +150,7 @@ Device::createDevice(DeviceManager& d, std::auto_ptr<ConfigRom>( configRom ))
                     return new Device(d, configRom);
             }
         case FW_VENDORID_ESI:
-            if (modelId == 0x00010064) {
+            if (modelId == 0x00010064 || modelId == 0x00000210) {
                 return new ESI::QuataFireDevice(d, configRom);
             }
             break;
@@ -835,7 +835,7 @@ Device::loadFromCache()
     std::string sDevicePath = getCachePath() + getConfigRom().getGuidString();
 
     char* configId;
-    asprintf(&configId, "%016"PRIx64"", getConfigurationId() );
+    asprintf(&configId, "%016" PRIx64 "", getConfigurationId() );
     if ( !configId ) {
         debugError( "could not create id string\n" );
         return false;
@@ -911,7 +911,7 @@ Device::saveCache()
 
     // come up with an unique file name for the current settings
     char* configId;
-    asprintf(&configId, "%016"PRIx64"", BeBoB::Device::getConfigurationId() );
+    asprintf(&configId, "%016" PRIx64 "", BeBoB::Device::getConfigurationId() );
     if ( !configId ) {
         debugError( "Could not create id string\n" );
         return false;
