@@ -33,6 +33,8 @@
 
 #include "libutil/ByteSwap.h"
 
+#include "ffadodevice.h"
+
 #include <cstdio>
 #include <cstring>
 #include <unistd.h>
@@ -241,7 +243,7 @@ BeBoB::BootloaderManager::downloadFirmware( std::string filename )
     using namespace std;
 
     printf( "parse BCD file\n" );
-    std::auto_ptr<BCD> bcd = std::auto_ptr<BCD>( new BCD( filename ) );
+    ffado_smartptr<BCD> bcd = ffado_smartptr<BCD>( new BCD( filename ) );
     if ( !bcd.get() ) {
         debugError( "downloadFirmware: Could not open or parse BCD '%s'\n",
                     filename.c_str() );
@@ -304,7 +306,7 @@ BeBoB::BootloaderManager::downloadCnE( std::string filename )
     using namespace std;
 
     printf( "parse BCD file\n" );
-    std::auto_ptr<BCD> bcd = std::auto_ptr<BCD>( new BCD( filename ) );
+    ffado_smartptr<BCD> bcd = ffado_smartptr<BCD>( new BCD( filename ) );
     if ( !bcd.get() ) {
         debugError( "downloadCnE: Could not open or parse BCD '%s'\n",
                     filename.c_str() );
@@ -537,7 +539,7 @@ BeBoB::BootloaderManager::downloadObject( BCD& bcd, EObjectType eObject )
             result = false;
         }
     }
-    printf( "download protocol successfuly completed\n" );
+    printf( "download protocol successfully completed\n" );
     return result;
 }
 
