@@ -28,7 +28,7 @@
 namespace BeBoB {
 namespace ESI {
 
-QuataFireDevice::QuataFireDevice( DeviceManager& d, std::auto_ptr<ConfigRom>( configRom ))
+QuataFireDevice::QuataFireDevice( DeviceManager& d, ffado_smartptr<ConfigRom>( configRom ))
     : BeBoB::Device( d, configRom)
 {
     m_fixed_clocksource.type = FFADODevice::eCT_Auto;
