@@ -191,9 +191,12 @@ Device::init_hardware(void)
     set_hardware_output_rec(0);
 
     if (ret==0 && m_rme_model==RME_MODEL_FIREFACE400 && provide_midi) {
-        // Precisely mirror the method used under other operating systems
-        // to set the high quadlet of the MIDI ARM address, even though it
-        // is a little inflexible.  We can refine this later if need be.
+        // Precisely mirror the method used under other operating systems to
+        // set the high quadlet of the MIDI ARM address, even though it is a
+        // little inflexible.  We can refine this later if need be.  This is
+        // only done if FFADO is providing MIDI functionality.  If not, the
+        // RME_FF400_MIDI_HIGH_ADDR is left alone for other drivers (such as
+        // snd-fireface in Linux kernel >= 4.12) to configure if desired.
         unsigned int node_id = getConfigRom().getNodeId();
         unsigned int midi_hi_addr;
         midi_hi_addr = 0x01;
@@ -207,7 +210,42 @@ Device::init_hardware(void)
     // which have a TCO.
     if (ret==0 && dev_config->tco_settings_valid==0) {
         if (dev_config->tco_present) {
+            FF_TCO_state_t tco_state;
             memset(tco_settings, 0, sizeof(*tco_settings));
+            if (read_tco_state(&tco_state) == 0) {
+                if (tco_state.ltc_valid) {
+                    tco_settings->input = FF_TCOPARAM_INPUT_LTC;
+                    switch (tco_state.frame_rate) {
+                        case FF_TCOSTATE_FRAMERATE_24fps:
+                            tco_settings->frame_rate = FF_TCOPARAM_FRAMERATE_24fps;
+                            break;
+                        case FF_TCOSTATE_FRAMERATE_25fps:
+                            tco_settings->frame_rate = FF_TCOPARAM_FRAMERATE_25fps;
+                            break;
+                        case FF_TCOSTATE_FRAMERATE_29_97fps:
+                            tco_settings->frame_rate = FF_TCOPARAM_FRAMERATE_29_97fps;
+                            break;
+                        case FF_TCOSTATE_FRAMERATE_30fps:
+                            tco_settings->frame_rate = FF_TCOPARAM_FRAMERATE_30fps;
+                        default:
+                            tco_settings->frame_rate = FF_TCOPARAM_FRAMERATE_25fps;
+                    }
+                    if (tco_state.drop_frame) {
+                        tco_settings->frame_rate += 1;
+                    }
+                } else {
+                    tco_settings->input = FF_TCOPARAM_INPUT_VIDEO;
+                    tco_settings->frame_rate = FF_TCOPARAM_FRAMERATE_25fps;
+                }
+                tco_settings->word_clock = FF_TCOPARAM_WORD_CLOCK_CONV_1_1;
+                tco_settings->sample_rate = ((settings->sample_rate % 48000)==0) ? 
+                    FF_TCOPARAM_SRATE_48 : FF_TCOPARAM_SRATE_44_1;
+                tco_settings->pull = FF_TCOPARAM_PULL_NONE;
+                tco_settings->termination = 0;
+                tco_settings->MTC = 0;
+            } else {
+                debugOutput(DEBUG_LEVEL_ERROR, "failed to read TCO state\n");
+            }
             if (write_tco_settings(tco_settings) != 0) {
                 debugOutput(DEBUG_LEVEL_ERROR, "failed to write TCO settings\n");
             }
@@ -507,8 +545,14 @@ Device::set_hardware_params(FF_software_settings_t *use_settings)
     /* Drop-and-stop is hardwired on in other drivers */
     data[2] |= CR2_DROP_AND_STOP;
 
-    if (m_rme_model == RME_MODEL_FIREFACE400) {
-        data[2] |= CR2_FF400_BIT;
+    if (m_rme_model==RME_MODEL_FIREFACE400 && !provide_midi) {
+        // If libffado is not providing MIDI, configure the register to
+        // allow snd-fireface (linux kernel >= 4.12) - or any other driver
+        // for the FF400 which might appear in future - to do so if desired. 
+        // The choice of tx address 1 matches that which is coded in
+        // snd-fireface as of kernel 4.12.
+        data[2] &= ~CR2_FF400_DISABLE_MIDI_TX_MASK;
+        data[2] |= CR2_FF400_SELECT_MIDI_TX_ADDR_1;
     }
 
     switch (sw_settings->sync_ref) {
@@ -582,7 +626,7 @@ Device::read_tco(quadlet_t *tco_data, signed int size)
         return -1;
 
     if (tco_data != NULL) {
-        for (i=0; i<(size<4)?size:4; i++)
+        for (i=0; i<((size<4)?size:4); i++)
             tco_data[i] = buf[i];
     }
 
@@ -747,7 +791,7 @@ Device::write_tco_settings(FF_TCO_settings_t *tco_settings)
     }
 
     switch (tco_settings->pull) {
-        case FF_TCPPARAM_PULL_NONE:
+        case FF_TCOPARAM_PULL_NONE:
             tc[2] |= FF_TCO2_PULL_0; break;
         case FF_TCOPARAM_PULL_UP_01:
             tc[2] |= FF_TCO2_PULL_UP_01; break;
@@ -858,7 +902,7 @@ debugOutput(DEBUG_LEVEL_VERBOSE,"*** starting: listen=%d, num_ch=%d\n", listen_c
             return -1;
         }
 
-debugOutput(DEBUG_LEVEL_VERBOSE, "start 0x%016"PRIx64" data: %08x\n", addr, data);
+debugOutput(DEBUG_LEVEL_VERBOSE, "start 0x%016" PRIx64 " data: %08x\n", addr, data);
         ret = writeRegister(addr, data);
 debugOutput(DEBUG_LEVEL_VERBOSE, "  ret=%d\n", ret);
         if (ret == 0) {
