@@ -42,7 +42,6 @@
 #include <stdint.h>
 #include <assert.h>
 #include <unistd.h>
-#include "libutil/ByteSwap.h"
 
 #include <iostream>
 #include <sstream>
@@ -57,28 +56,8 @@
 
 namespace Rme {
 
-// The RME devices expect packet data in little endian format (as
-// opposed to bus order, which is big endian).  Therefore define our own
-// 32-bit byteswap function to account for this.
-#if __BYTE_ORDER == __BIG_ENDIAN
-#define RME_BYTESWAP32(x)       ByteSwap32(x)
-#else
-#define RME_BYTESWAP32(x)       (x)
-#endif
-
-static inline uint32_t
-ByteSwapToDevice32(uint32_t d)
-{
-    return RME_BYTESWAP32(d);
-}
-static inline uint32_t
-ByteSwapFromDevice32(uint32_t d)
-{
-    return RME_BYTESWAP32(d);
-}
-
 Device::Device( DeviceManager& d,
-                      std::auto_ptr<ConfigRom>( configRom ))
+                      ffado_smartptr<ConfigRom>( configRom ))
     : FFADODevice( d, configRom )
     , m_rme_model( RME_MODEL_NONE )
     , settings( NULL )
@@ -87,7 +66,7 @@ Device::Device( DeviceManager& d,
     , num_channels( 0 )
     , frames_per_packet( 0 )
     , speed800( 0 )
-    , provide_midi( 0 )
+    , provide_midi( 0 )    // MIDI not currently implemented in FFADO
     , iso_tx_channel( -1 )
     , iso_rx_channel( -1 )
     , m_receiveProcessor( NULL )
@@ -227,6 +206,49 @@ Device::buildMixer() {
         result &= m_ControlContainer->addElement(
             new RmeSettingsCtrl(*this, RME_CTRL_INSTRUMENT_OPTIONS, 1,
                 "Chan1_instr_opts", "Input instrument options channel 1", ""));
+
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_LTC_IN, 0,
+                "Tco_ltc_in", "TCO input LTC received", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_INPUT_LTC_VALID, 0,
+                "Tco_input_ltc_valid", "TCO input LTC valid", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_INPUT_LTC_FPS, 0,
+                "Tco_input_ltc_fps", "TCO input LTC frame rate ID", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_INPUT_LTC_DROPFRAME, 0,
+                "Tco_input_ltc_dropframe", "TCO input LTC dropframe detected", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_INPUT_VIDEO_TYPE, 0,
+                "Tco_input_video_type", "TCO input video type", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_INPUT_WORD_CLK, 0,
+                "Tco_input_word_clk", "TCO input word clock type", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_INPUT_LOCK, 0,
+                "Tco_input_lock", "TCO input is locked", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_SYNC_SRC, 0,
+                "Tco_sync_src", "TCO sync source", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_VIDEO_IN_TERM, 0,
+                "Tco_video_in_term", "TCO video input terminator is enabled", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_WORD_CLK_CONV, 0,
+                "Tco_word_clk_conv", "TCO word clock conversion", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_FREQ, 0,
+                "Tco_freq", "TCO measured frequency (Hz)", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_FRAME_RATE, 0,
+                "Tco_frame_rate", "TCO frame rate ID", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_SAMPLE_RATE, 0,
+                "Tco_sample_rate", "TCO sample rate ID", ""));
+        result &= m_ControlContainer->addElement(
+            new RmeSettingsCtrl(*this, RME_CTRL_TCO_SAMPLE_RATE_OFS, 0,
+                "Tco_sample_rate_ofs", "TCO sample rate pulldown offset ID", ""));
     }
 
     if (m_rme_model == RME_MODEL_FIREFACE400) {
@@ -348,7 +370,7 @@ Device::probe( Util::Configuration& c, ConfigRom& configRom, bool generic )
 }
 
 FFADODevice *
-Device::createDevice(DeviceManager& d, std::auto_ptr<ConfigRom>( configRom ))
+Device::createDevice(DeviceManager& d, ffado_smartptr<ConfigRom>( configRom ))
 {
     return new Device(d, configRom );
 }
@@ -731,7 +753,7 @@ Device::resetForStreaming() {
     // sent to it and the rx stream will fail to start.
     err = hardware_init_streaming(dev_config->hardware_freq, iso_tx_channel) != 0;
     if (err) {
-        debugFatal("Could not intialise device streaming system\n");
+        debugFatal("Could not initialise device streaming system\n");
         return false;
     }
 
@@ -1133,7 +1155,7 @@ Device::readRegister(fb_nodeaddr_t reg) {
     
     quadlet = 0;
     if (get1394Service().read(0xffc0 | getNodeId(), reg, 1, &quadlet) <= 0) {
-        debugError("Error doing RME read from register 0x%06"PRIx64"\n",reg);
+        debugError("Error doing RME read from register 0x%06" PRIx64 "\n",reg);
     }
     return ByteSwapFromDevice32(quadlet);
 }
@@ -1144,7 +1166,7 @@ Device::readBlock(fb_nodeaddr_t reg, quadlet_t *buf, unsigned int n_quads) {
     unsigned int i;
 
     if (get1394Service().read(0xffc0 | getNodeId(), reg, n_quads, buf) <= 0) {
-        debugError("Error doing RME block read of %d quadlets from register 0x%06"PRIx64"\n",
+        debugError("Error doing RME block read of %d quadlets from register 0x%06" PRIx64 "\n",
             n_quads, reg);
         return -1;
     }
@@ -1162,7 +1184,7 @@ Device::writeRegister(fb_nodeaddr_t reg, quadlet_t data) {
     data = ByteSwapToDevice32(data);
     if (get1394Service().write(0xffc0 | getNodeId(), reg, 1, &data) <= 0) {
         err = 1;
-        debugError("Error doing RME write to register 0x%06"PRIx64"\n",reg);
+        debugError("Error doing RME write to register 0x%06" PRIx64 "\n",reg);
     }
 
     return (err==0)?0:-1;
@@ -1183,7 +1205,7 @@ Device::writeBlock(fb_nodeaddr_t reg, quadlet_t *data, unsigned int n_quads) {
     }
     if (get1394Service().write(0xffc0 | getNodeId(), reg, n_quads, data) <= 0) {
         err = 1;
-        debugError("Error doing RME block write of %d quadlets to register 0x%06"PRIx64"\n",
+        debugError("Error doing RME block write of %d quadlets to register 0x%06" PRIx64 "\n",
           n_quads, reg);
     }
 
