@@ -20,10 +20,12 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from PyQt4.QtCore import SIGNAL, SLOT, QObject, Qt, QTimer
-from PyQt4.QtGui import QWidget, QHBoxLayout, QVBoxLayout, \
-                        QGroupBox, QTabWidget, QLabel, \
-                        QPushButton, QToolButton, QSpacerItem, QSizePolicy
+# from PyQt4.QtCore import Qt, QTimer
+# from PyQt4.QtGui import QWidget, QHBoxLayout, QVBoxLayout
+# from PyQt4.QtGui import QGroupBox, QTabWidget, QLabel
+# from PyQt4.QtGui import QPushButton, QToolButton, QSpacerItem, QSizePolicy
+from ffado.import_pyqt import *
+
 from ffado.config import *
 import logging
 log = logging.getLogger('audiofire')
@@ -141,12 +143,12 @@ class AudioFire(QWidget):
     def updateDigIfaceControl(self, a0):
         sender = self.sender()
         state = a0
-	# 0/2/3 is available but GUI set 0/1/2
+        # 0/2/3 is available but GUI set 0/1/2
         if a0 > 0:
             state += 1
         log.debug("set %s to %d" % (
             self.DigIfaceControls[sender][0], state))
-	self.hw.setDiscrete(self.DigIfaceControls[sender][0], state)
+        self.hw.setDiscrete(self.DigIfaceControls[sender][0], state)
 
     def updatePlbkRouteControl(self, src):
         sender = self.sender()
@@ -179,7 +181,7 @@ class AudioFire(QWidget):
         outputtabs = QTabWidget(self)
         outputtabslayout.addWidget( outputtabs, 1 )
 
-        for outpair in range(nb_pys_out/2):
+        for outpair in range(int(nb_pys_out/2)):
             tab = QWidget( outputtabs )
             tablayout = QHBoxLayout( tab )
             
@@ -200,7 +202,7 @@ class AudioFire(QWidget):
             grpMonitorLayout = QHBoxLayout()
             grpMonitor.setLayout(grpMonitorLayout);
             output_id = outpair * 2
-            for inpair in range(nb_pys_in/2):
+            for inpair in range(int(nb_pys_in/2)):
                 # create GUI elements
                 strip = AfMonitorWidget( grpMonitor )
                 grpMonitorLayout.addWidget( strip, 1 )
@@ -349,7 +351,7 @@ class AudioFire(QWidget):
     def initValues(self):
         log.debug("Init values")
 
-        for ctrl, info in self.MatrixVolumeControls.iteritems():
+        for ctrl, info in self.MatrixVolumeControls.items():
             vol = self.hw.getMatrixMixerValue(self.MatrixVolumeControls[ctrl][0],
                                                 self.MatrixVolumeControls[ctrl][1],
                                                 self.MatrixVolumeControls[ctrl][2])
@@ -359,9 +361,9 @@ class AudioFire(QWidget):
             ctrl.setValue(vol)
 
             # connect the UI element
-            QObject.connect(ctrl,SIGNAL('valueChanged(int)'),self.updateMatrixVolume)
+            ctrl.valueChanged.connect(self.updateMatrixVolume)
 
-        for ctrl, info in self.MatrixButtonControls.iteritems():
+        for ctrl, info in self.MatrixButtonControls.items():
             state = self.hw.getMatrixMixerValue(self.MatrixButtonControls[ctrl][0],
                                                 self.MatrixButtonControls[ctrl][1],
                                                 self.MatrixButtonControls[ctrl][2])
@@ -373,9 +375,9 @@ class AudioFire(QWidget):
                 ctrl.setChecked(False)
 
             # connect the UI element
-            QObject.connect(ctrl,SIGNAL('clicked(bool)'),self.updateMatrixButton)
+            ctrl.clicked.connect(self.updateMatrixButton)
 
-        for ctrl, info in self.MatrixRotaryControls.iteritems():
+        for ctrl, info in self.MatrixRotaryControls.items():
             vol = self.hw.getMatrixMixerValue(self.MatrixRotaryControls[ctrl][0],
                                                 self.MatrixRotaryControls[ctrl][1],
                                                 self.MatrixRotaryControls[ctrl][2])
@@ -384,9 +386,9 @@ class AudioFire(QWidget):
             ctrl.setValue(vol)
 
             # connect the UI element
-            QObject.connect(ctrl,SIGNAL('valueChanged(int)'),self.updateMatrixRotary)
+            ctrl.valueChanged.connect(self.updateMatrixRotary)
 
-        for ctrl, info in self.VolumeControls.iteritems():
+        for ctrl, info in self.VolumeControls.items():
             vol = self.hw.getContignuous(self.VolumeControls[ctrl][0])
 
             #vol = 0x01000000-vol
@@ -394,9 +396,9 @@ class AudioFire(QWidget):
             ctrl.setValue(vol)
 
             # connect the UI element
-            QObject.connect(ctrl,SIGNAL('valueChanged(int)'),self.updateVolume)
+            ctrl.valueChanged.connect(self.updateVolume)
 
-        for ctrl, info in self.SelectorControls.iteritems():
+        for ctrl, info in self.SelectorControls.items():
             state = self.hw.getDiscrete(self.SelectorControls[ctrl][0])
             log.debug("%s state is %d" % (ctrl.objectName() , state))
             if state:
@@ -405,13 +407,13 @@ class AudioFire(QWidget):
                 ctrl.setChecked(False)
 
             # connect the UI element
-            QObject.connect(ctrl,SIGNAL('clicked(bool)'),self.updateSelector)
+            ctrl.clicked.connect(self.updateSelector)
 
-        for ctrl, info in self.TriggerControls.iteritems():
+        for ctrl, info in self.TriggerControls.items():
             # connect the UI element
-            QObject.connect(ctrl,SIGNAL('clicked()'),self.updateTrigger)
+            ctrl.clicked.connect(self.updateTrigger)
 
-        for ctrl, info in self.SPDIFmodeControls.iteritems():
+        for ctrl, info in self.SPDIFmodeControls.items():
             state = self.hw.getDiscrete(self.SPDIFmodeControls[ctrl][0])
             log.debug("%s state is %d" % (ctrl.objectName() , state))
             if state == self.SPDIFmodeControls[ctrl][1]:
@@ -420,25 +422,25 @@ class AudioFire(QWidget):
                 ctrl.setChecked(False)
 
             # connect the UI element
-            QObject.connect(ctrl,SIGNAL('toggled(bool)'),self.updateSPDIFmodeControl)
+            ctrl.toggled.connect(self.updateSPDIFmodeControl)
 
-        for ctrl, info in self.DigIfaceControls.iteritems():
+        for ctrl, info in self.DigIfaceControls.items():
             state = self.hw.getDiscrete(self.DigIfaceControls[ctrl][0])
             # 0/2/3 is available but GUI set 0/1/2
             if state > 0:
                 state -= 1
             ctrl.setCurrentIndex(state)
-            QObject.connect(ctrl, SIGNAL('activated(int)'), self.updateDigIfaceControl)
+            ctrl.activated.connect(self.updateDigIfaceControl)
 
-        for ctrl, info in self.PlbkRouteControls.iteritems():
+        for ctrl, info in self.PlbkRouteControls.items():
             sink = self.PlbkRouteControls[ctrl][1]
             src = self.hw.getDiscrete(self.PlbkRouteControls[ctrl][0], sink)
             ctrl.setCurrentIndex(src)
             self.setStreamLabel(src, sink)
-            QObject.connect(ctrl, SIGNAL('activated(int)'), self.updatePlbkRouteControl)
+            ctrl.activated.connect(self.updatePlbkRouteControl)
 
         self.update_timer = QTimer(self)
-        QObject.connect(self.update_timer, SIGNAL('timeout()'), self.polledUpdate)
+        self.update_timer.timeout.connect(self.polledUpdate)
         self.update_timer.start(1000)
         self.streaming_state = -1
 
