@@ -18,7 +18,10 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from PyQt4 import QtGui, QtCore, Qt
+# from PyQt4 import QtGui, QtCore, Qt
+# from PyQt4.QtGui import QWidget, QScrollArea
+from ffado.import_pyqt import *
+
 import dbus
 
 from ffado.widgets.matrixmixer import MatrixMixer
@@ -29,6 +32,9 @@ from ffado.config import *
 
 class BooleanControl:
     def __init__(self, hw, path):
+        if bypassdbus:
+            self.value = False
+            return
         self.iface = dbus.Interface(
                 hw.bus.get_object(hw.servername, path),
                 dbus_interface="org.ffado.Control.Element.Boolean")
@@ -38,6 +44,8 @@ class BooleanControl:
         return self.value
 
     def select(self, n):
+        if bypassdbus:
+            return False
         if self.iface.select(n):
             self.value = n
             return True
@@ -45,6 +53,9 @@ class BooleanControl:
 
 class DiscreteControl:
     def __init__(self, hw, path):
+        if bypassdbus:
+            self.value = 0
+            return
         self.iface = dbus.Interface(
                 hw.bus.get_object(hw.servername, path),
                 dbus_interface="org.ffado.Control.Element.Discrete")
@@ -63,13 +74,29 @@ class Saffire_Dice(Generic_Dice_EAP):
         Generic_Dice_EAP.__init__(self, parent)
 
     def buildMixer(self):
-        #print self.hw
-        #print self.hw.getText("/Generic/Nickname")
+        #print( self.hw )
+        #print( self.hw.getText("/Generic/Nickname") )
         Generic_Dice_EAP.buildMixer(self)
 
-        widget = QtGui.QWidget()
+        widget = QWidget()
+
+        ModelName = self.configrom.getModelName().rstrip()
+        if ffado.config.bypassdbus:
+            # A hack for the bypassdbus case, where ModelName has a slightly
+            # different format.  Rather than using the name as returned by
+            # the device (eg: "SAFFIRE_PRO_40"), the name is taken from the
+            # configuration file desciption (eg: "Saffire PRO 40").
+            if ModelName[-2:] == "-1":
+                ModelName = ModelName[:-2]
+            if ModelName[-4:] == " DSP":
+                ModelName = ModelName[:-4]
+            ModelNum = ModelName[-2:]
+            ModelName = "SAFFIRE_PRO"
+            if ModelNum != "26":
+                ModelName += "_"
+            ModelName += ModelNum
+            print( ModelName )
 
-        ModelName = self.configrom.getModelName()
         if  ModelName == "SAFFIRE_PRO_14":
             uicLoad("ffado/mixer/Saffire_Pro14_monitoring.ui", widget)
         elif ModelName == "SAFFIRE_PRO_24" or self.configrom.getModelName() == "SAFFIRE_PRO_24DSP":
@@ -80,7 +107,7 @@ class Saffire_Dice(Generic_Dice_EAP):
             uicLoad("ffado/mixer/Saffire_Pro40_monitoring.ui", widget)
 
         # Add Monitoring to ffado-mixer panels
-        scrollarea = QtGui.QScrollArea(self.tabs)
+        scrollarea = QScrollArea(self.tabs)
         scrollarea.setWidgetResizable(False)
         scrollarea.setWidget(widget)
         self.tabs.addTab(scrollarea, "Monitoring")
@@ -88,14 +115,14 @@ class Saffire_Dice(Generic_Dice_EAP):
         # Global settings
         self.muteInterface = BooleanControl(self.hw, self.hw.basepath+"/EAP/Monitoring/GlobalMute/State")
         widget.GlobalMute.setChecked(self.muteInterface.selected())
-        self.connect(widget.GlobalMute, QtCore.SIGNAL("toggled(bool)"), self.muteToggle)
+        widget.GlobalMute.toggled.connect(self.muteToggle)
 
         self.dimInterface = BooleanControl(self.hw, self.hw.basepath+"/EAP/Monitoring/GlobalDim/State")
         widget.GlobalDim.setChecked(self.dimInterface.selected())
-        self.connect(widget.GlobalDim, QtCore.SIGNAL("toggled(bool)"), self.dimToggle)
+        widget.GlobalDim.toggled.connect(self.dimToggle)
         self.dimLevelInterface = DiscreteControl(self.hw, self.hw.basepath+"/EAP/Monitoring/GlobalDim/Level")
         widget.DimLevel.setValue(self.dimLevelInterface.getvalue())
-        self.connect(widget.DimLevel, QtCore.SIGNAL("valueChanged(int)"), self.dimLevelChanged)
+        widget.DimLevel.valueChanged.connect(self.dimLevelChanged)
         self.DimLevel = widget.DimLevel
         widget.DimLevel.setEnabled(self.dimInterface.selected())
 
@@ -256,7 +283,7 @@ class Saffire_Dice(Generic_Dice_EAP):
             # Adat/Spdif switch control from interface for Pro40
             self.adatSpdifInterface = BooleanControl(self.hw, self.hw.basepath+"/EAP/Monitoring/AdatSpdif/State")
             widget.AdatSpdif.setChecked(self.adatSpdifInterface.selected())
-            self.connect(widget.AdatSpdif, QtCore.SIGNAL("toggled(bool)"), self.adatSpdifToggle)
+            widget.AdatSpdif.toggled.connect(self.adatSpdifToggle)
 
         if ModelName in ("SAFFIRE_PRO_14", "SAFFIRE_PRO_24"):
             # Line/Inst and Hi/Lo switches for Pro14 and 24
@@ -272,7 +299,7 @@ class Saffire_Dice(Generic_Dice_EAP):
             self.LineInSwitches.append(p)
             for i in range(4):
                 self.LineInSwitches[i].widget.setChecked(self.LineInSwitches[i].Interface.selected())
-                self.connect(self.LineInSwitches[i].widget, QtCore.SIGNAL("toggled(bool)"), self.LineInSwitches[i].Interface.select)
+                self.LineInSwitches[i].widget.toggled.connect(self.LineInSwitches[i].Interface.select)
             widget.LineInSwitchLine_1.setChecked(not self.LineInSwitches[0].Interface.selected())
             widget.LineInSwitchLine_2.setChecked(not self.LineInSwitches[1].Interface.selected())
             widget.LineInSwitchLo_3.setChecked(not self.LineInSwitches[2].Interface.selected())
@@ -280,26 +307,25 @@ class Saffire_Dice(Generic_Dice_EAP):
 
         # Mono/Stereo Switch
         if ModelName != "SAFFIRE_PRO26":
-            for i in range(self.nbLines/2):
+            for i in range(int(self.nbLines/2)):
                 self.LineMonos[i].widget.setChecked(self.LineMonos[i].Interface.selected())
-                self.connect(self.LineMonos[i].widget, QtCore.SIGNAL("toggled(bool)"), self.LineMonos[i].Interface.select)
-
+                self.LineMonos[i].widget.toggled.connect(self.LineMonos[i].Interface.select)
 
         for i in range(self.nbLines):
             self.LineUnActivates[i].widget.setChecked(self.LineUnActivates[i].Interface.selected())
-            self.connect(self.LineUnActivates[i].widget, QtCore.SIGNAL("toggled(bool)"), self.LineUnActivates[i].Interface.select)
+            self.LineUnActivates[i].widget.toggled.connect(self.LineUnActivates[i].Interface.select)
             self.LineMutes[i].widget.setChecked(self.LineMutes[i].Interface.selected())
-            self.connect(self.LineMutes[i].widget, QtCore.SIGNAL("toggled(bool)"), self.LineMutes[i].Interface.select)
+            self.LineMutes[i].widget.toggled.connect(self.LineMutes[i].Interface.select)
             self.LineGMutes[i].widget.setChecked(self.LineGMutes[i].Interface.selected())
-            self.connect(self.LineGMutes[i].widget, QtCore.SIGNAL("toggled(bool)"), self.LineGMutes[i].Interface.select)
+            self.LineGMutes[i].widget.toggled.connect(self.LineGMutes[i].Interface.select)
             self.LineGDims[i].widget.setChecked(self.LineGDims[i].Interface.selected())
-            self.connect(self.LineGDims[i].widget, QtCore.SIGNAL("toggled(bool)"), self.LineGDims[i].Interface.select)
+            self.LineGDims[i].widget.toggled.connect(self.LineGDims[i].Interface.select)
             self.LineVolumes[i].widget.setValue(self.LineVolumes[i].Interface.getvalue())
-            self.connect(self.LineVolumes[i].widget, QtCore.SIGNAL("valueChanged(int)"), self.LineVolumes[i].Interface.setvalue)
+            self.LineVolumes[i].widget.valueChanged.connect(self.LineVolumes[i].Interface.setvalue)
  
         # HW switch controls the possibility of monitoring each output separatly 
         widget.HWSwitch.setChecked(self.HWselected())
-        self.connect(widget.HWSwitch, QtCore.SIGNAL("toggled(bool)"), self.HWToggle)
+        widget.HWSwitch.toggled.connect(self.HWToggle)
 
         # Line Out monitoring enabling depends on H/W switch
         self.LineOut = widget.LineOut
